# Paniw et al."We do not study the effects of climate change on mammal populations where and how we should"
# Script written by Maria Paniw
# March 30, 2020
# R version 4.0.0

# This code demonstrates how projections of temperature and precipitation 
# were linked to demographic-rate responses to relevant climatic drivers 
# to estimate the direction of future responses to climate

# For more detail, see the "Climate-change projections" section in the methods
library(dplyr)
##### Load reviewed demograohy studies

# set working directory:
setwd("/Users/maria/Dropbox/synthesisClimChangeVertebrates/manuscript sections/")

data=read.csv("mammal_review_extracted_studies.csv")
# Please not that the information of future porjections of precipitation and temperature is already included in the .csv
# This script is meant to allow replication of the analyses. We therefore remove the columns containing projections:

data=data[,-which(colnames(data)%in%c("tmin" ,"tmax","prec", "tmean","tmin.sd" ,"tmax.sd","prec.sd", "tmean.sd"))]

# And reset categorisations of changes in climatic drivers

data$future.driver.direction=data$future.driver..direction.from.study


# Unique longitud and latitude combinations
data$lon_lat=paste(data$lon,data$lat)

## climate data (CHELSA downloads)

hist=read.csv("chelsa_1979-2013_29.10.2019.csv")

proj=read.csv("proj_29.10.2019.csv")

# historical averages(1979-2013)

hist$lon_lat=paste(hist$Longitude,hist$Latitude)
proj$lon_lat=paste(proj$Longitude,proj$Latitude)

# fix some naming issues
colnames(proj)[4]="month"
proj$variable=factor(proj$variable)
levels(proj$variable)=c("tmax","tmean","tmin","prec")

# Remove outliers
hist$value[hist$variable%in%c("tmin","tmax")&(hist$value>60|hist$value<(-60))]=NA
hist$value[hist$variable%in%c("prec")&(hist$value>1000|hist$value<(-1000))]=NA
proj$value[proj$variable%in%c("prec")&(proj$value>1000|proj$value<(-1000))]=NA

#check ditribution of climate

hist(hist$value[hist$variable%in%c("prec")])
hist(hist$value[hist$variable%in%c("tmin")])
hist(hist$value[hist$variable%in%c("tmax")])
hist(hist$value[hist$variable%in%c("tmean")])

# monthly averages for each uniqiue location 
hist.mu=aggregate(value~lon_lat+month+variable,mean,data=hist,na.rm=T)

# Standard deviation of monthly averages for each uniqiue location 
hist.sd=aggregate(value~lon_lat+variable,sd,data=hist.mu,na.rm=T)


#check ditribution of projected climate

hist(proj$value[proj$variable%in%c("prec")])
hist(proj$value[proj$variable%in%c("tmin")])
hist(proj$value[proj$variable%in%c("tmax")])
hist(proj$value[proj$variable%in%c("tmean")])

# mean and CI projected across 5 models
proj.mu=aggregate(value~lon_lat+month+variable,mean,data=proj,na.rm=T)
proj.mu$ub=aggregate(value~lon_lat+month+variable,quantile,0.975,data=proj,na.rm=T)$value
proj.mu$lb=aggregate(value~lon_lat+month+variable,quantile,0.025,data=proj,na.rm=T)$value

# SD and CI projected across 5 models
proj.sd.m=aggregate(value~lon_lat+mod+variable,sd,data=proj,na.rm=T)
proj.sd=aggregate(value~lon_lat+variable,mean,data=proj.sd.m,na.rm=T)
proj.sd$ub=aggregate(value~lon_lat+variable,quantile,0.975,data=proj.sd.m,na.rm=T)$value
proj.sd$lb=aggregate(value~lon_lat+variable,quantile,0.025,data=proj.sd.m,na.rm=T)$value

colnames(proj.mu)[4]="proj"
colnames(proj.sd)[3]="proj"

# Join historic averages and sd with projected
proj.mu$hist=left_join(proj.mu,hist.mu,by=c("lon_lat","month","variable"))$value
proj.sd$hist=left_join(proj.sd,hist.sd,by=c("lon_lat","variable"))$value

# What is absolute change in values?
proj.mu$change=proj.mu$proj-proj.mu$hist
proj.sd$change=proj.sd$proj-proj.sd$hist

# If the absolute change crosses the lower or upper CI boundary, consider it to be 0
proj.mu$change[proj.mu$hist>=proj.mu$lb&proj.mu$hist<=proj.mu$ub&!is.na(proj.mu$change)] = 0
proj.sd$change[proj.sd$hist>=proj.sd$lb&proj.sd$hist<=proj.sd$ub&!is.na(proj.sd$change)] = 0


# Last step: calculate average changes across all months
clim.change=aggregate(change~lon_lat+variable,mean,data=proj.mu,na.rm=T)

# Categorise as decrease, increase, or no change
clim.change$changeCat=NA
clim.change$changeCat[clim.change$change<0&!is.na(clim.change$change)]="decrease"
clim.change$changeCat[clim.change$change>0&!is.na(clim.change$change)]="increase"
clim.change$changeCat[clim.change$change==0&!is.na(clim.change$change)]="no change"

proj.sd$changeCat=NA
proj.sd$changeCat[proj.sd$change<0&!is.na(proj.sd$change)]="decrease"
proj.sd$changeCat[proj.sd$change>0&!is.na(proj.sd$change)]="increase"
proj.sd$changeCat[proj.sd$change==0&!is.na(proj.sd$change)]="no change"

# link to main data 
data$tmin=left_join(data,clim.change[clim.change$variable=="tmin",],by="lon_lat")$changeCat
data$tmax=left_join(data,clim.change[clim.change$variable=="tmax",],by="lon_lat")$changeCat
data$prec=left_join(data,clim.change[clim.change$variable=="prec",],by="lon_lat")$changeCat
data$tmean=left_join(data,clim.change[clim.change$variable=="tmean",],by="lon_lat")$changeCat

data$tmin.sd=left_join(data,proj.sd[proj.sd$variable=="tmin",],by="lon_lat")$changeCat
data$tmax.sd=left_join(data,proj.sd[proj.sd$variable=="tmax",],by="lon_lat")$changeCat
data$prec.sd=left_join(data,proj.sd[proj.sd$variable=="prec",],by="lon_lat")$changeCat
data$tmean.sd=left_join(data,proj.sd[proj.sd$variable=="tmean",],by="lon_lat")$changeCat

# Fill in projected changes in climatic drivers where they have not been recorded:
data$future.driver.direction=as.character(data$future.driver.direction)

# Average precipitation
data$future.driver.direction[is.na(data$future.driver.direction)&
                                      data$climatic.driver%in%c("p")&!data$aggregation.method%in%c("sd","SD","depth")]=data$prec[(is.na(data$future.driver.direction))&
                                                                                                                                          data$climatic.driver%in%c("p")&!data$aggregation.method%in%c("sd","SD","depth")]

# SD precipitation
data$future.driver.direction[(is.na(data$future.driver.direction))&
                                      data$climatic.driver=="p"&data$aggregation.method%in%c("sd","SD")]=data$prec.sd[(is.na(data$future.driver.direction))&
                                                                                                                               data$climatic.driver=="p"&data$aggregation.method%in%c("sd","SD")]
# Maximum temperature
data$future.driver.direction[(is.na(data$future.driver.direction))&
                                      data$climatic.driver=="t"&data$aggregation.method%in%c("max")]=data$tmax[(is.na(data$future.driver.direction))&
                                                                                                                 data$climatic.driver=="t"&data$aggregation.method%in%c("max")]


# Average temperature
data$future.driver.direction[(is.na(data$future.driver.direction))&
                                      data$climatic.driver=="t"&data$aggregation.method%in%c("mean","a","mean ","mean(min)")]=data$tmean[(is.na(data$future.driver.direction))&
                                                                                                                                                  data$climatic.driver=="t"&data$aggregation.method%in%c("mean","a","mean ","mean(min)")]                                                                                                                                  

# Minimum temperature
data$future.driver.direction[(is.na(data$future.driver.direction))&
                                      data$climatic.driver=="t"&data$aggregation.method%in%c("min")]=data$tmin[(is.na(data$future.driver.direction))&
                                                                                                                        data$climatic.driver=="t"&data$aggregation.method%in%c("min")] 

# SD temperature
data$future.driver.direction[(is.na(data$future.driver.direction))&
                                      data$climatic.driver=="t"&data$aggregation.method%in%c("sd","SD")]=data$tmean.sd[(is.na(data$future.driver.direction))&
                                                                                                                                data$climatic.driver=="t"&data$aggregation.method%in%c("sd","SD")] 

# context-dependent changes
data$future.driver.direction[!data$future.driver.direction%in%c("no change")&data$climatic.driver%in%c("t","p")&data$aggregation.method%in%c("sd","SD","min","mean","a","mean ","mean(min)","max","depth")&data$direction.of.effect%in%c("context-dependent")]="context-dependent"


# Projected changes in demographic rates
data$projected.change.in.demographic.rate=NA

data$projected.change.in.demographic.rate[data$direction.of.effect%in%c("noe")&data$future.driver.direction%in%c("increase","decrease","context-dependent")]="NOE"
data$projected.change.in.demographic.rate[data$future.driver.direction.change%in%c("no change")]="NOE"
data$projected.change.in.demographic.rate[!data$direction.of.effect%in%c("noe")&data$future.driver.direction%in%c("context-dependent")]="context-dependent"
data$projected.change.in.demographic.rate[data$direction.of.effect%in%c("neg")&data$future.driver.direction%in%c("increase")]="decrease"
data$projected.change.in.demographic.rate[data$direction.of.effect%in%c("neg")&data$future.driver.direction%in%c("decrease")]="increase"
data$projected.change.in.demographic.rate[data$direction.of.effect%in%c("pos")&data$future.driver.directione%in%c("increase")]="increase"
data$projected.change.in.demographic.rate[data$direction.of.effect%in%c("pos")&data$future.driver.direction%in%c("decrease")]="decrease"
